@@ -47,7 +47,7 @@ class ConsoleSpinner(SpinnerBase):
         self._live = Live(
             self._generate_spinner_panel(),
             console=self.console,
-            refresh_per_second=10,
+            refresh_per_second=20,
             transient=True,
             auto_refresh=False,  # Don't auto-refresh to avoid wiping out user input
         )
@@ -103,6 +103,11 @@ class ConsoleSpinner(SpinnerBase):
 
         text.append(self.current_frame, style="bold cyan")
 
+        context_info = SpinnerBase.get_context_info()
+        if context_info:
+            text.append(" ")
+            text.append(context_info, style="bold white")
+
         # Return a simple Text object instead of a Panel for a cleaner look
         return text
 
